==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/DataLegendSummaryColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendSeriesValueInfoDescriptionMetadata } from "./DataLegendSeriesValueInfoDescriptionMetadata";
import { DataLegendSummaryColumnDescription } from "./DataLegendSummaryColumnDescription";
/**
 * @hidden
 */
export let DataLegendSummaryColumnDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataLegendSummaryColumnDescriptionMetadata extends Base {
        static b(a) {
            if (DataLegendSummaryColumnDescriptionMetadata.a == null) {
                DataLegendSummaryColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataLegendSummaryColumnDescriptionMetadata.c(DataLegendSummaryColumnDescriptionMetadata.a);
            }
            if (a.j(DataLegendSummaryColumnDescriptionMetadata.a)) {
                return;
            }
            a.y(DataLegendSummaryColumnDescriptionMetadata.a);
        }
        static c(a) {
            DataLegendSeriesValueInfoDescriptionMetadata.c(a);
        }
        static d(a) {
            DataLegendSummaryColumnDescriptionMetadata.b(a);
            a.aa("DataLegendSummaryColumn", () => new DataLegendSummaryColumnDescription());
            a.z("DataLegendSummaryColumn", DataLegendSummaryColumnDescriptionMetadata.a);
        }
    }
    DataLegendSummaryColumnDescriptionMetadata.$t = /*@__PURE__*/ markType(DataLegendSummaryColumnDescriptionMetadata, 'DataLegendSummaryColumnDescriptionMetadata');
    DataLegendSummaryColumnDescriptionMetadata.a = null;
    return DataLegendSummaryColumnDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/DataLegendSummaryColumnDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendSeriesValueInfoDescriptionMetadata } from "./DataLegendSeriesValueInfoDescriptionMetadata";
import { DataLegendSummaryColumnDescription } from "./DataLegendSummaryColumnDescription";
/**
 * @hidden
 */
export let DataLegendSummaryColumnDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataLegendSummaryColumnDescriptionMetadata extends Base {
        static b(a) {
            if (DataLegendSummaryColumnDescriptionMetadata.a == null) {
                DataLegendSummaryColumnDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataLegendSummaryColumnDescriptionMetadata.c(DataLegendSummaryColumnDescriptionMetadata.a);
            }
            if (a.k(DataLegendSummaryColumnDescriptionMetadata.a)) {
                return;
            }
            a.aa(DataLegendSummaryColumnDescriptionMetadata.a);
        }
        static c(a) {
            DataLegendSeriesValueInfoDescriptionMetadata.c(a);
        }
        static d(a) {
            DataLegendSummaryColumnDescriptionMetadata.b(a);
            a.ac("DataLegendSummaryColumn", () => new DataLegendSummaryColumnDescription());
            a.ab("DataLegendSummaryColumn", DataLegendSummaryColumnDescriptionMetadata.a);
        }
    }
    DataLegendSummaryColumnDescriptionMetadata.$t = /*@__PURE__*/ markType(DataLegendSummaryColumnDescriptionMetadata, 'DataLegendSummaryColumnDescriptionMetadata');
    DataLegendSummaryColumnDescriptionMetadata.a = null;
    return DataLegendSummaryColumnDescriptionMetadata;
})();
